<?php
/**
 * Product quantity inputs
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/quantity-input.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.8.0
 *
 * @var bool   $readonly If the input should be set to readonly mode.
 * @var string $type     The input type attribute.
 */

defined( 'ABSPATH' ) || exit;
?>
    <?php
    /**
     * Hook to output something before the quantity input field.
     *
     * @since 7.2.0
     */
    do_action( 'woocommerce_before_quantity_input_field' );
    ?>
	<p class="qnt-wrap prod-li-qnt">
		<a href="#" class="qnt-minus prod-li-minus"><?php echo esc_html__('-', 'motor'); ?></a>
		<input
            type="<?php echo esc_attr( $type ); ?>"
            <?php echo $readonly ? 'readonly="readonly"' : ''; ?>
            id="<?php echo esc_attr( $input_id ); ?>"
            name="<?php echo esc_attr( $input_name ); ?>"
            data-qnt-price="<?php if (!empty($args['price'])) echo esc_attr($args['price']); ?>"
			data-decimals="<?php echo wc_get_price_decimals(); ?>" 
			data-thousand_separator="<?php echo wc_get_price_thousand_separator(); ?>" 
			data-decimal_separator="<?php echo wc_get_price_decimal_separator(); ?>" 
			data-currency="<?php echo get_woocommerce_currency_symbol(); ?>" 
			data-price_format="<?php echo get_woocommerce_price_format(); ?>"
            value="<?php echo esc_attr( $input_value ); ?>"
            aria-label="<?php esc_attr_e( 'Product quantity', 'motor' ); ?>"
            class="input-text qty text"
            size="4"
            min="<?php echo esc_attr( $min_value ); ?>"
            max="<?php echo esc_attr( 0 < $max_value ? $max_value : '' ); ?>"
            pattern="<?php echo esc_attr( $pattern ); ?>"

			<?php if ( ! $readonly ): ?>
                step="<?php echo esc_attr( $step ); ?>"
                placeholder="<?php echo esc_attr( $placeholder ); ?>"
                inputmode="<?php echo esc_attr( $inputmode ); ?>"
                autocomplete="<?php echo esc_attr( isset( $autocomplete ) ? $autocomplete : 'on' ); ?>"
			<?php endif; ?>
		>
		<a href="#" class="qnt-plus prod-li-plus"><?php echo esc_html__('+', 'motor'); ?></a>
	</p>
    <?php
    /**
     * Hook to output something after quantity input field
     *
     * @since 3.6.0
     */
    do_action( 'woocommerce_after_quantity_input_field' );
    ?>
<?php
